pub struct PROGRESS_BAR { /* private fields */ }Methods from Deref<Target = ProgressBar>
Sourcepub fn set_style(&self, style: ProgressStyle)
pub fn set_style(&self, style: ProgressStyle)
Overrides the stored style.
This does not redraw the bar. Call tick to force it.
Sourcepub fn enable_steady_tick(&self, ms: u64)
pub fn enable_steady_tick(&self, ms: u64)
Spawns a background thread to tick the progress bar.
When this is enabled a background thread will regularly tick the progress back in the given interval (milliseconds). This is useful to advance progress bars that are very slow by themselves.
When steady ticks are enabled calling .tick() on a progress
bar does not do anything.
Sourcepub fn disable_steady_tick(&self)
pub fn disable_steady_tick(&self)
Undoes enable_steady_tick.
Sourcepub fn set_draw_delta(&self, n: u64)
pub fn set_draw_delta(&self, n: u64)
Limit redrawing of progress bar to every n steps. Defaults to 0.
By default, the progress bar will redraw whenever its state advances. This setting is helpful in situations where the overhead of redrawing the progress bar dominates the computation whose progress is being reported.
If n is greater than 0, operations that change the progress bar such
as .tick(), .set_message() and .set_length() will no longer cause
the progress bar to be redrawn, and will only be shown once the
position advances by n steps.
let n = 1_000_000;
let pb = ProgressBar::new(n);
pb.set_draw_delta(n / 100); // redraw every 1% of additional progressSourcepub fn tick(&self)
pub fn tick(&self)
Manually ticks the spinner or progress bar.
This automatically happens on any other change to a progress bar.
A quick convenience check if the progress bar is hidden.
Sourcepub fn println<I>(&self, msg: I)
pub fn println<I>(&self, msg: I)
Print a log line above the progress bar.
If the progress bar was added to a MultiProgress, the log line will be
printed above all other progress bars.
Note that if the progress bar is hidden (which by default happens if the progress bar is redirected into a file) println will not do anything either.
Sourcepub fn set_position(&self, pos: u64)
pub fn set_position(&self, pos: u64)
Sets the position of the progress bar.
Sourcepub fn set_length(&self, len: u64)
pub fn set_length(&self, len: u64)
Sets the length of the progress bar.
Sourcepub fn set_prefix(&self, prefix: &str)
pub fn set_prefix(&self, prefix: &str)
Sets the current prefix of the progress bar.
Sourcepub fn set_message(&self, msg: &str)
pub fn set_message(&self, msg: &str)
Sets the current message of the progress bar.
Sourcepub fn reset_eta(&self)
pub fn reset_eta(&self)
Resets the ETA calculation.
This can be useful if progress bars make a huge jump or were paused for a prolonged time.
Sourcepub fn finish_with_message(&self, msg: &str)
pub fn finish_with_message(&self, msg: &str)
Finishes the progress bar and sets a message.
Sourcepub fn finish_and_clear(&self)
pub fn finish_and_clear(&self)
Finishes the progress bar and completely clears it.
Sourcepub fn set_draw_target(&self, target: ProgressDrawTarget)
pub fn set_draw_target(&self, target: ProgressDrawTarget)
Sets a different draw target for the progress bar.
This can be used to draw the progress bar to stderr for instance:
let pb = ProgressBar::new(100);
pb.set_draw_target(ProgressDrawTarget::stderr());Sourcepub fn wrap_iter<It>(&self, it: It) -> ProgressBarIter<It>where
It: Iterator,
pub fn wrap_iter<It>(&self, it: It) -> ProgressBarIter<It>where
It: Iterator,
Wraps an iterator with the progress bar.
let v = vec![1, 2, 3];
let pb = ProgressBar::new(3);
for item in pb.wrap_iter(v.iter()) {
// ...
}Sourcepub fn wrap_read<R>(&self, read: R) -> ProgressBarRead<R>where
R: Read,
pub fn wrap_read<R>(&self, read: R) -> ProgressBarRead<R>where
R: Read,
Wraps a Reader with the progress bar.
let source = File::open("work.txt")?;
let mut target = File::create("done.txt")?;
let pb = ProgressBar::new(source.metadata()?.len());
io::copy(&mut pb.wrap_read(source), &mut target);Trait Implementations
Sourceimpl Deref for PROGRESS_BAR
impl Deref for PROGRESS_BAR
Sourcetype Target = ProgressBar
type Target = ProgressBar
Sourcefn deref(&self) -> &ProgressBar
fn deref(&self) -> &ProgressBar
impl LazyStatic for PROGRESS_BAR